==> aws-rfdk-0.26.0.tar.gz: package/lib/deadline/test/asset-constants.d.ts <==
/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0
 */
import { CWA_ASSET_LINUX, CWA_ASSET_WINDOWS } from '../../core/test/asset-constants';
export { CWA_ASSET_LINUX, CWA_ASSET_WINDOWS, };
export declare const CONFIG_WORKER_ASSET_LINUX: {
    Bucket: string;
    Key: string;
};
export declare const CONFIG_WORKER_ASSET_WINDOWS: {
    Bucket: string;
    Key: string;
};
export declare const CONFIG_WORKER_PORT_ASSET_WINDOWS: {
    Bucket: string;
    Key: string;
};
export declare const INSTALL_REPOSITORY_ASSET_LINUX: {
    Bucket: import("@aws-cdk/assert").PropertyMatcher;
};
export declare const TEST_ASSET: {
    Bucket: import("@aws-cdk/assert").PropertyMatcher;
    Key: import("@aws-cdk/assert").PropertyMatcher;
};
export declare const REPO_DC_ASSET: {
    Bucket: import("@aws-cdk/assert").PropertyMatcher;
    Key: import("@aws-cdk/assert").PropertyMatcher;
};
export declare const RQ_CONNECTION_ASSET: {
    Bucket: string;
    Key: string;
};
export declare function linuxConfigureWorkerScriptBoilerplate(scriptParams: string): (string | {
    'Fn::Select': (number | {
        'Fn::Split': (string | {
            Ref: string;
        })[];
    })[];
    Ref?: undefined;
} | {
    Ref: string;
    'Fn::Select'?: undefined;
})[];
export declare function linuxCloudWatchScriptBoilerplate(): (string | {
    'Fn::Select': (number | {
        'Fn::Split': (string | {
            Ref: string;
        })[];
    })[];
    Ref?: undefined;
} | {
    Ref: string;
    'Fn::Select'?: undefined;
})[];
export declare function windowsConfigureWorkerScriptBoilerplate(scriptParams: string): (string | {
    'Fn::Select': (number | {
        'Fn::Split': (string | {
            Ref: string;
        })[];
    })[];
    Ref?: undefined;
} | {
    Ref: string;
    'Fn::Select'?: undefined;
})[];
export declare function windowsCloudWatchScriptBoilerplate(): (string | {
    'Fn::Select': (number | {
        'Fn::Split': (string | {
            Ref: string;
        })[];
    })[];
    Ref?: undefined;
} | {
    Ref: string;
    'Fn::Select'?: undefined;
})[];

==> aws-rfdk-0.27.0.tar.gz: package/lib/deadline/test/asset-constants.d.ts <==
/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0
 */
import { CWA_ASSET_LINUX, CWA_ASSET_WINDOWS } from '../../core/test/asset-constants';
export { CWA_ASSET_LINUX, CWA_ASSET_WINDOWS, };
export declare const CONFIG_WORKER_ASSET_LINUX: {
    Bucket: string;
    Key: string;
};
export declare const CONFIG_WORKER_ASSET_WINDOWS: {
    Bucket: string;
    Key: string;
};
export declare const CONFIG_WORKER_PORT_ASSET_WINDOWS: {
    Bucket: string;
    Key: string;
};
export declare const INSTALL_REPOSITORY_ASSET_LINUX: {
    Bucket: import("@aws-cdk/assert").PropertyMatcher;
};
export declare const TEST_ASSET: {
    Bucket: import("@aws-cdk/assert").PropertyMatcher;
    Key: import("@aws-cdk/assert").PropertyMatcher;
};
export declare const REPO_DC_ASSET: {
    Bucket: import("@aws-cdk/assert").PropertyMatcher;
    Key: import("@aws-cdk/assert").PropertyMatcher;
};
export declare const RQ_CONNECTION_ASSET: {
    Bucket: string;
    Key: string;
};
export declare function linuxCloudWatchScriptBoilerplate(scriptParams: string): (string | {
    'Fn::Select': (number | {
        'Fn::Split': (string | {
            Ref: string;
        })[];
    })[];
    Ref?: undefined;
} | {
    Ref: string;
    'Fn::Select'?: undefined;
})[];
export declare function linuxConfigureWorkerScriptBoilerplate(scriptParams: string): (string | {
    'Fn::Select': (number | {
        'Fn::Split': (string | {
            Ref: string;
        })[];
    })[];
    Ref?: undefined;
} | {
    Ref: string;
    'Fn::Select'?: undefined;
})[];
export declare function windowsCloudWatchScriptBoilerplate(scriptParams: string): (string | {
    'Fn::Select': (number | {
        'Fn::Split': (string | {
            Ref: string;
        })[];
    })[];
    Ref?: undefined;
} | {
    Ref: string;
    'Fn::Select'?: undefined;
})[];
export declare function windowsConfigureWorkerScriptBoilerplate(scriptParams: string): (string | {
    'Fn::Select': (number | {
        'Fn::Split': (string | {
            Ref: string;
        })[];
    })[];
    Ref?: undefined;
} | {
    Ref: string;
    'Fn::Select'?: undefined;
})[];
